"use strict";

exports.__esModule = true;
exports.default = void 0;
var _lambdaHandler = require("./lambda-handler");
var _routeHandler = require("./route-handler");
// just for debugging
// import { inspect } from "util"

// eslint-disable-next-line @typescript-eslint/no-empty-interface

async function getCacheUtils() {
  if (process.env.NETLIFY) {
    const CACHE_DIR = `/opt/build/cache`;
    return (await import(`@netlify/cache-utils`)).bindOpts({
      cacheDir: CACHE_DIR
    });
  }
  return undefined;
}
const createNetlifyAdapter = () => {
  return {
    name: `gatsby-adapter-netlify`,
    cache: {
      async restore({
        directories,
        reporter
      }) {
        reporter.info(`[gatsby-adapter-netlify] cache.restore() ${directories}`);
        const utils = await getCacheUtils();
        if (utils) {
          reporter.info(`[gatsby-adapter-netlify] using @netlify/cache-utils restore`);
          return await utils.restore(directories);
        }
        return false;
      },
      async store({
        directories,
        reporter
      }) {
        reporter.info(`[gatsby-adapter-netlify] cache.store() ${directories}`);
        const utils = await getCacheUtils();
        if (utils) {
          reporter.info(`[gatsby-adapter-netlify] using @netlify/cache-utils save`);
          await utils.save(directories);
        }
      }
    },
    async adapt({
      routesManifest,
      functionsManifest
    }) {
      // this is noisy, so for now commented out to easily restore if some routes/functions debugging is needed
      // console.log(
      //   `[gatsby-adapter-netlify] adapt()`,
      //   inspect(
      //     {
      //       routesManifest,
      //       functionsManifest,
      //     },
      //     { depth: Infinity, colors: true }
      //   )
      // )

      const {
        lambdasThatUseCaching
      } = await (0, _routeHandler.handleRoutesManifest)(routesManifest);

      // functions handling
      for (const fun of functionsManifest) {
        await (0, _lambdaHandler.prepareFunctionVariants)(fun, lambdasThatUseCaching.get(fun.functionId));
      }
    }
  };
};
var _default = createNetlifyAdapter;
exports.default = _default;